@@ -4,13 +4,14 @@ import toml
 
 import click
 
-from search_that_hash.cracker import cracking
+from search_that_hash.cracker import handler
 from search_that_hash import config_object
 from search_that_hash import printing
 
 import logging
 import coloredlogs
 
+
 @click.command()
 @click.option("--text", "-t", type=str, help="Crack a single hash")
 @click.option(
@@ -21,7 +22,7 @@ import coloredlogs
     help="The file of hashes, seperated by newlines.",
 )
 @click.option("-w", "--wordlist", type=str, required=False, help="The wordlist.")
-@click.option("--timeout", type=int, help="Choose timeout time in second", default=1)
+@click.option("--timeout", type=int, help="Choose timeout time in second", default=2)
 @click.option("--hashcat", is_flag=True, help="Runs Hashcat instead of John")
 @click.option("-g", "--greppable", is_flag=True, help="Used to grep")
 @click.option(
@@ -47,25 +48,25 @@ import coloredlogs
 )
 @click.option("--accessible", is_flag=True, help="Makes the output accessible.")
 @click.option("--no-banner", is_flag=True, help="Doesn't print banner.")
-
 def main(**kwargs):
     """
     Search-That-Hash - The fastest way to crack any hash.
     \n
     GitHub:\n
-        https://github.com/HashPals/Search-That-Hash\n
+            https://github.com/HashPals/Search-That-Hash\n
     Discord:\n
-        https://discord.gg/CswayhQ8Ru
+            https://discord.gg/CswayhQ8Ru
     \n
     Usage:
     \n
-        sth --text "5f4dcc3b5aa765d61d8327deb882cf99"
+            sth --text "5f4dcc3b5aa765d61d8327deb882cf99"
     """
-    
-    levels = {1:logging.WARNING,2:logging.INFO,3:logging.DEBUG}
-    try:
-        coloredlogs.install(level=levels[kwargs['verbose']])
-    except:
+
+    levels = {1: logging.WARNING, 2: logging.INFO, 3: logging.DEBUG}
+
+    if kwargs["verbose"] and kwargs["verbose"] <= 3:
+        coloredlogs.install(level=levels[kwargs["verbose"]])
+    else:
         # Verobosity was not given so it removes logging
         coloredlogs.install(level=logging.CRITICAL)
 
@@ -77,15 +78,12 @@ def main(**kwargs):
     if not kwargs["greppable"] and not kwargs["accessible"] and not kwargs["no_banner"]:
         logging.info("Printing banner")
         printing.Prettifier.banner()
-    
-    searcher = cracking.Searcher(config)
-    results = cracking.Searcher.main(searcher)
-    
-    if kwargs["greppable"]:
-        logging.info("Printing greppable results")
-        printing.Prettifier.greppable_print(results)
+
+    cracking_handler = handler.Handler(config)
+    cracking_handler.start()
 
     exit(0)
 
+
 if __name__ == "__main__":
     main()
